@@ -8,10 +8,10 @@
 #define GLIBMM_MAJOR_VERSION 2
 
 /* Minor version number of glibmm. */
-#define GLIBMM_MINOR_VERSION 74
+#define GLIBMM_MINOR_VERSION 78
 
 /* Micro version number of glibmm. */
-#define GLIBMM_MICRO_VERSION 0
+#define GLIBMM_MICRO_VERSION 1
 
 /* Define if glibmm is built as a static library */
 /* #undef GLIBMM_STATIC_LIB */
@@ -19,6 +19,18 @@
 /* The size of wchar_t, as computed by sizeof. */
 #define GLIBMM_SIZEOF_WCHAR_T 4
 
+/* The size of short, as computed by sizeof. */
+#define GLIBMM_SIZEOF_SHORT 2
+
+/* The size of int, as computed by sizeof. */
+#define GLIBMM_SIZEOF_INT 4
+
+/* The size of long, as computed by sizeof. */
+#define GLIBMM_SIZEOF_LONG 4
+
+/* The size of long long, as computed by sizeof. */
+#define GLIBMM_SIZEOF_LONG_LONG 8
+
 /* Defined when the -Ddebug-refcounting configure argument was given */
 /* #undef GLIBMM_DEBUG_REFCOUNTING */
 
